@@ -1,6 +1,6 @@
 /*
  *   stunnel       TLS offloading and load-balancing proxy
- *   Copyright (C) 1998-2016 Michal Trojnara <Michal.Trojnara@stunnel.org>
+ *   Copyright (C) 1998-2017 Michal Trojnara <Michal.Trojnara@stunnel.org>
  *
  *   This program is free software; you can redistribute it and/or modify it
  *   under the terms of the GNU General Public License as published by the
@@ -255,9 +255,8 @@ void ui_new_log(const char *line) {
 
 /**************************************** ctx callbacks */
 
-int passwd_cb(char *buf, int size, int rwflag, void *userdata) {
-    (void)userdata; /* squash the unused parameter warning */
-    return PEM_def_callback(buf, size, rwflag, NULL);
+int ui_passwd_cb(char *buf, int size, int rwflag, void *userdata) {
+    return PEM_def_callback(buf, size, rwflag, userdata);
 }
 
 #ifndef OPENSSL_NO_ENGINE
